Contains custom functions for automating some repitive actions during notebook use and python development

## Installation
`pip install vpk_custom_functions`

## How to use?
`from vpk_custom_functions import general_settings`
`from vpk_custom_functions import activate_parent`
